==> idmtools-1.6.1-py3-none-any.whl: idmtools/entities/command_task.py <==
from dataclasses import dataclass, field
from typing import List, Callable, Type, Union, TYPE_CHECKING
from idmtools.assets import AssetCollection
from idmtools.entities.itask import ITask
from idmtools.registry.task_specification import TaskSpecification

if TYPE_CHECKING:  # pragma: no cover
    from idmtools.entities.iplatform import IPlatform
    from idmtools.entities.iworkflow_item import IWorkflowItem
    from idmtools.entities.simulation import Simulation


@dataclass()
class CommandTask(ITask):
    #: Hooks to gather common assets
    gather_common_asset_hooks: List[Callable[[ITask], AssetCollection]] = field(default_factory=list)
    #: Hooks to gather transient assets
    gather_transient_asset_hooks: List[Callable[[ITask], AssetCollection]] = field(default_factory=list)
    """
    Defines an extensible simple task that implements functionality through optional supplied use hooks
    """

    def __post_init__(self):
        super().__post_init__()
        if self.command is None:
            raise ValueError("Command is required")

    def gather_common_assets(self) -> AssetCollection:
        """
        Gather common(experiment-level) assets for task

        Returns:
            AssetCollection containing common assets
        """
        # TODO validate hooks have expected return type
        ac = AssetCollection()
        for x in self.gather_common_asset_hooks:
            ac += x(self)
        ac += self.common_assets
        return ac

    def gather_transient_assets(self) -> AssetCollection:
        """
        Gather transient(experiment-level) assets for task

        Returns:
            AssetCollection containing transient assets
        """
        ac = AssetCollection()
        for x in self.gather_transient_asset_hooks:
            ac += x(self)
        ac += self.transient_assets
        if len(ac.assets) != 0:
            self.transient_assets = ac
        return ac

    def reload_from_simulation(self, simulation: 'Simulation'):  # noqa: F821
        pass

    def pre_creation(self, parent: Union['Simulation', 'IWorkflowItem'], platform: 'IPlatform'):
        super().pre_creation(parent, platform)
        if platform.is_windows_platform():
            self.command.is_windows = True


class CommandTaskSpecification(TaskSpecification):
    def get(self, configuration: dict) -> CommandTask:
        """
        Get instance of CommandTask with configuration

        Args:
            configuration: configuration for CommandTask

        Returns:
            CommandTask with configuration
        """
        return CommandTask(**configuration)

    def get_description(self) -> str:
        """
        Get description of plugin

        Returns:
            Plugin description
        """
        return "Defines a general command that provides user hooks. Intended for use in advanced scenarios"

    def get_example_urls(self) -> List[str]:
        """
        Get example urls related to CommandTask

        Returns:
            List of urls that have examples related to CommandTask
        """
        return ['https://github.com/InstituteforDiseaseModeling/corvid-idmtools']

    def get_type(self) -> Type[CommandTask]:
        """
        Get task type provided by plugin

        Returns:
            CommandTask
        """
        return CommandTask

    def get_version(self) -> str:
        from idmtools import __version__
        return __version__

==> idmtools-1.6.3-py3-none-any.whl: idmtools/entities/command_task.py <==
from dataclasses import dataclass, field
from typing import List, Callable, Type, Union, TYPE_CHECKING
from idmtools.assets import AssetCollection
from idmtools.entities.itask import ITask
from idmtools.registry.task_specification import TaskSpecification
from idmtools.entities.simulation import Simulation

if TYPE_CHECKING:  # pragma: no cover
    from idmtools.entities.iplatform import IPlatform
    from idmtools.entities.iworkflow_item import IWorkflowItem


@dataclass()
class CommandTask(ITask):
    #: Hooks to gather common assets
    gather_common_asset_hooks: List[Callable[[ITask], AssetCollection]] = field(default_factory=list)
    #: Hooks to gather transient assets
    gather_transient_asset_hooks: List[Callable[[ITask], AssetCollection]] = field(default_factory=list)
    """
    Defines an extensible simple task that implements functionality through optional supplied use hooks
    """

    def __post_init__(self):
        super().__post_init__()
        if self.command is None:
            raise ValueError("Command is required")

    def gather_common_assets(self) -> AssetCollection:
        """
        Gather common(experiment-level) assets for task

        Returns:
            AssetCollection containing common assets
        """
        # TODO validate hooks have expected return type
        ac = AssetCollection()
        for x in self.gather_common_asset_hooks:
            ac += x(self)
        ac += self.common_assets
        return ac

    def gather_transient_assets(self) -> AssetCollection:
        """
        Gather transient(experiment-level) assets for task

        Returns:
            AssetCollection containing transient assets
        """
        ac = AssetCollection()
        for x in self.gather_transient_asset_hooks:
            ac += x(self)
        ac += self.transient_assets
        if len(ac.assets) != 0:
            self.transient_assets = ac
        return ac

    def reload_from_simulation(self, simulation: 'Simulation'):  # noqa: F821
        pass

    def pre_creation(self, parent: Union['Simulation', 'IWorkflowItem'], platform: 'IPlatform'):
        super().pre_creation(parent, platform)
        if platform.is_windows_platform(parent):
            self.command.is_windows = True


class CommandTaskSpecification(TaskSpecification):
    def get(self, configuration: dict) -> CommandTask:
        """
        Get instance of CommandTask with configuration

        Args:
            configuration: configuration for CommandTask

        Returns:
            CommandTask with configuration
        """
        return CommandTask(**configuration)

    def get_description(self) -> str:
        """
        Get description of plugin

        Returns:
            Plugin description
        """
        return "Defines a general command that provides user hooks. Intended for use in advanced scenarios"

    def get_example_urls(self) -> List[str]:
        """
        Get example urls related to CommandTask

        Returns:
            List of urls that have examples related to CommandTask
        """
        return ['https://github.com/InstituteforDiseaseModeling/corvid-idmtools']

    def get_type(self) -> Type[CommandTask]:
        """
        Get task type provided by plugin

        Returns:
            CommandTask
        """
        return CommandTask

    def get_version(self) -> str:
        from idmtools import __version__
        return __version__
